# IBM(c) 2007 EPL license http://www.eclipse.org/legal/epl-v10.html
package xCAT_schema::ISNM;

#################################################################################
# This is a sample code that contains the user defined user database schema defination.
# Here is a list of things you can do to add DB tables to xCAT database.
#   1  Copy this file to /opt/xcat/lib/perl/xCAT_schema directory, rename it
#      to your chosen schema name. 
#   2  Change the word Sample above to be the same as the file name you chose.
#   3  Do NOT change the variable name "%tabspec".
#   4  x_lljob and x_llnode are the sample table names. 
#      jobid, status, node, jobstatus are the sample column names. 
#      Change them to your like. Please make sure all table names start with "x_".
#      Each table must have a 'disable' and comments column.
#      Please do not use SQL reserved words for your table names and column names.
#      Use this site to check the reserved words: 
#         http://www.petefreitag.com/tools/sql_reserved_words_checker/  
#   5 Change the keys.
#   6 Change the data types. For SQLite
#           the  default data type is TEXT if not specified.
#     The supported data types are: 
#        REAL,CHAR,TEXT,DATE,TIME,FLOAT,BIGINT,DOUBLE,STRING,
#        BINARY,DECIMAL,BOOLEAN,INTEGER,VARCHAR,SMALLINT,TIMESTAMP
#     Please note that SQLight only supports: INTEGER, REAL, TEXT, BLOB. 
#     xCAT support MySQL, PostgreSQL and DB2 also, supported data types
#     depend on the database you are using. 
#   7 Change the table descriptions and column descriptions to your like.
#   8 Restart the the xcatd, the tables will be automatically generated. 
#   9 If you have service nodes,  copy all the files to those also and restart
#     the daemon.
# 
###############################################################################
%tabspec = (
    isnm_perf => {     
        cols => [qw(perfid time_stamp supernode chipid period globalcounter comments disable)],  
        keys => [qw(perfid)],
        required => [qw(perfid)],
        types => {
            perfid => 'DECIMAL(20,0)',
            time_stamp => 'TIMESTAMP DEFAULT CURRENT_TIMESTAMP',
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            globalcounter => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Main Performance Table',
        engine => 'InnoDB',
    },

    isnm_perf_lllink => {  
        cols => [qw(perfid supernode chipid period linknumber cyclesblocked flitssent flitsdropped comments disable)], 
        keys => [qw(perfid linknumber)],
        required => [qw(perfid linknumber)],
        types => {
            perfid => 'DECIMAL(20,0)',
            supernode => 'INTEGER',
            chipid => 'INTEGER',
	    period => 'INTEGER',
            linknumber => 'INTEGER',
            cyclesblocked => 'DECIMAL(20,0)',
            flitssent => 'DECIMAL(20,0)',
            flitsdropped => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores LL link counters',
        engine => 'InnoDB',
    },

    isnm_perf_lrlink => {
        cols => [qw(perfid supernode chipid period linknumber cyclesblocked flitssent flitsdropped linklevelretries comments disable)],
        keys => [qw(perfid linknumber)],
        required => [qw(perfid linknumber)],
        types => {
            perfid => 'DECIMAL(20,0)',
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            linknumber => 'INTEGER',
            cyclesblocked => 'DECIMAL(20,0)',
            flitssent => 'DECIMAL(20,0)',
            flitsdropped => 'DECIMAL(20,0)',
            linklevelretries => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores LR link counters',
        engine => 'InnoDB',
    },
 
    isnm_perf_dlink => {
        cols => [qw(perfid supernode chipid period linknumber cyclesblocked flitssent flitsdropped linklevelretries comments disable)],
        keys => [qw(perfid linknumber)],
        required => [qw(perfID linkNumber)],
        types => {
            perfid => 'DECIMAL(20,0)',
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            linknumber => 'INTEGER',
            cyclesblocked => 'DECIMAL(20,0)',
            flitssent => 'DECIMAL(20,0)',
            flitsdropped => 'DECIMAL(20,0)',
            linklevelretries => 'INTEGER',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores D link counters',
        engine => 'InnoDB',
    },

    isnm_perf_isr => {
        cols => [qw(perfid supernode chipid period hfi_id flitssent flitsdropped comments disable)],
        keys => [qw(perfid hfi_id)],
        required => [qw(perfID hfi_id)],
        types => {
            perfid => 'DECIMAL(20,0)',
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            hfi_id => 'INTEGER',
            flitssent => 'DECIMAL(20,0)',
            flitsdropped => 'DECIMAL(20,0)',
            linklevelretries => 'INTEGER',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores ISR-HFI link counters',
        engine => 'InnoDB',
    },

    isnm_perf_hfi => {
        cols => [qw(perfid supernode chipid period hfinumber packetssent packetsdroppedsend packetrecieved packetsdroppedreceive immediateppacketsend sendreceivepacketsent fullrdmapacketsent halfrdmapacketsent smallrdmapacketsent ippacketsent caupacketsent gupspacketsent comments disable)],
        keys => [qw(perfid hfinumber)],
        required => [qw(perfid hfinumber)],
        types => {
            perfid => 'DECIMAL(20,0)',
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            hfinumber => 'INTEGER',
            packetssent => 'DECIMAL(20,0)',
            packetsdroppedsend => 'DECIMAL(20,0)',
            packetrecieved => 'DECIMAL(20,0)',
            packetsdroppedreceive => 'DECIMAL(20,0)',
            immediateppacketsend => 'DECIMAL(20,0)',
            sendreceivepacketsent => 'DECIMAL(20,0)',
            fullrdmapacketsent => 'DECIMAL(20,0)',
            halfrdmapacketsent => 'DECIMAL(20,0)',
            smallrdmapacketsent => 'DECIMAL(20,0)',
            ippacketsent => 'DECIMAL(20,0)',
            caupacketsent => 'DECIMAL(20,0)',
            gupspacketsent => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores HFI aggregate counters',
        engine => 'InnoDB',
    },
  
    isnm_perf_sum => {
        cols => [qw(time_stamp period comments disable)],
        keys => [qw(period)],
        required => [qw(period)],
        types => {
            time_stamp => 'TIMESTAMP DEFAULT CURRENT_TIMESTAMP',
            period => 'INTEGER',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Main Performance summary Table',
        engine => 'InnoDB',
    },

    isnm_perf_lllink_sum => {
        cols => [qw(supernode chipid period linknumber cyclesblockedavg flitssentavg flitsdroppedavg comments disable)],
        keys => [qw(period linknumber supernode chipid)],
        required => [qw(period linknumber supernode chipid)],
        types => {
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            linknumber => 'INTEGER',
            cyclesblockedavg => 'DECIMAL(20,0)',
            flitssentavg => 'DECIMAL(20,0)',
            flitsdroppedavg => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores LL link summary counters',
        engine => 'InnoDB',
    },

    isnm_perf_lrlink_sum => {
        cols => [qw(supernode chipid period linknumber cyclesblockedavg flitssentavg flitsdroppedavg linklevelretriesavg comments disable)],
        keys => [qw(period linknumber supernode chipid)],
        required => [qw(period linkNumber supernode chipid)],
        types => {
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            linknumber => 'INTEGER',
            cyclesblockedavg => 'DECIMAL(20,0)',
            flitssentavg => 'DECIMAL(20,0)',
            flitsdroppedavg => 'DECIMAL(20,0)',
            linklevelretriesavg => 'INTEGER',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores LR link summary counters',
        engine => 'InnoDB',
    },

    isnm_perf_dlink_sum => {
        cols => [qw(supernode chipid period linknumber cyclesblockedavg flitssentavg flitsdroppedavg linklevelretriesavg comments disable)],
        keys => [qw(period linknumber supernode chipid)],
        required => [qw(period linknumber supernode chipid)],
        types => {
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            linknumber => 'INTEGER',
            cyclesblockedavg => 'DECIMAL(20,0)',
            flitssentavg => 'DECIMAL(20,0)',
            flitsdroppedavg => 'DECIMAL(20,0)',
            linklevelretriesavg => 'INTEGER',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores D link summary counters',
        engine => 'InnoDB',
    },
 
    isnm_perf_isr_sum => {
        cols => [qw(supernode chipid period hfi_id flitssentavg flitsdroppedavg comments disable)],
        keys => [qw(period hfi_id supernode chipid)],
        required => [qw(period hfi_id supernode chipid)],
        types => {
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            linknumber => 'INTEGER',
            flitssentavg => 'DECIMAL(20,0)',
            flitsdroppedavg => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K',
        table_desc => 'Stores ISR-HFI link summary counters',
        engine => 'InnoDB',
    },

    isnm_perf_hfi_sum => {
        cols => [qw(supernode chipid period hfinumber packetssentavg packetsdroppedsendavg packetrecievedavg packetsdroppedreceiveavg immediateppacketsendavg sendreceivepacketsentavg fullrdmapacketsentavg halfrdmapacketsentavg smallrdmapacketsentavg ippacketsentavg caupacketsentavg gupspacketsentavg comments disable)],
        keys => [qw(period hfinumber supernode chipid)],
        required => [qw(period hfinumber supernode chipid)],
        types => {
            supernode => 'INTEGER',
            chipid => 'INTEGER',
            period => 'INTEGER',
            hfinumber => 'INTEGER',
            packetssentavg => 'DECIMAL(20,0)',
            packetsdroppedsendavg => 'DECIMAL(20,0)',
            packetrecievedavg => 'DECIMAL(20,0)',
            packetsdroppedreceiveavg => 'DECIMAL(20,0)',
            immediateppacketsendavg => 'DECIMAL(20,0)',
            sendreceivepacketsentavg => 'DECIMAL(20,0)',
            fullrdmapacketsentavg => 'DECIMAL(20,0)',
            halfrdmapacketsentavg => 'DECIMAL(20,0)',
            smallrdmapacketsentavg => 'DECIMAL(20,0)',
            ippacketsentavg => 'DECIMAL(20,0)',
            caupacketsentavg => 'DECIMAL(20,0)',
            gupspacketsentavg => 'DECIMAL(20,0)',
        },
        tablespace =>'XCATTBS32K', 
        table_desc => 'Stores ISR-HFI link summary counters',
        engine => 'InnoDB',
    },

    isnm_config => {
        cols => [qw(config_parm config_value comments disable)],
        keys => [qw(config_parm)],
        required => [qw(config_parm)],
        types => {
            config_parm => 'VARCHAR(80)',
            config_value => 'INTEGER',
        },
        table_desc => 'Stores configuration parameters for various ISNM functions.',
        engine => 'InnoDB',
        descriptions => {
            config_parm => 'The name of the configuration parameter.',
            config_value => 'The value of the configuration parameter.',
            comments => 'ISNM configuration parameters.',
            disable => "yes",
        },
    },

); # end of tabspec definition

1;
