-- IBM_PROLOG_BEGIN_TAG 
-- This is an automatically generated prolog. 
--  
--  
--  
-- Licensed Materials - Property of IBM 
--  
-- Restricted Materials of IBM 
--  
-- (C) COPYRIGHT International Business Machines Corp. 2010,2012 
-- All Rights Reserved 
--  
-- US Government Users Restricted Rights - Use, duplication or 
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 
--  
-- IBM_PROLOG_END_TAG 
-- ISNM_mysql.sql
-- Author: Wesley D. Jones
-- USES XCAT TO CREATE STORED PROCEDURES, VIEWS, FOREIGN KEYS

-- DROP PROCEDURES IF THEY ALREADY EXIST
DROP PROCEDURE IF EXISTS SP_GETLLAVERAGE;
DROP PROCEDURE IF EXISTS SP_GETLRAVERAGE;
DROP PROCEDURE IF EXISTS SP_GETDAVERAGE;
DROP PROCEDURE IF EXISTS SP_GETISRAVERAGE;
DROP PROCEDURE IF EXISTS SP_GETHFIAVERAGE;

-- DROP VIEWS IF THEY ALREADY EXIST
DROP VIEW IF EXISTS VNM_xcat_site;
DROP VIEW IF EXISTS VNM_xcat_nodelist;
DROP VIEW IF EXISTS VNM_xcat_ppc;

-- CREATE STORED PROCEDURES
delimiter //
-- CREATE STORED PROCEDURE TO AVERAGE LL LINKS
CREATE PROCEDURE SP_GETLLAVERAGE(IN InSupernode integer, IN InChipID integer, IN InLinkNumber integer)
BEGIN
        INSERT INTO isnm_perf_lllink_sum(period,supernode,chipid,linknumber,cyclesblockedavg,flitssentavg,flitsdroppedavg)
        SELECT period,supernode,chipid,linknumber,AVG(cyclesblocked),AVG(flitssent),AVG(flitsdropped) FROM isnm_perf_lllink
        WHERE (supernode = InSupernode AND chipid = InChipID AND linknumber = InLinkNumber)
        GROUP BY period,supernode,chipid,linknumber;
END;

-- CREATE STORED PROCEDURE TO AVERAGE LR LINKS
CREATE PROCEDURE SP_GETLRAVERAGE(IN InSupernode integer, IN InChipID integer, IN InLinkNumber integer)
BEGIN
        INSERT INTO isnm_perf_lrlink_sum(period,supernode,chipid,linknumber,cyclesblockedavg,flitssentavg,flitsdroppedavg,linklevelretriesavg)
        SELECT period,supernode,chipid,linknumber,AVG(cyclesblocked),AVG(flitssent),AVG(flitsdropped),AVG(linklevelretries) FROM isnm_perf_lrlink
        WHERE (supernode = InSupernode AND chipid = InChipID AND linknumber = InLinkNumber)
        GROUP BY period,supernode,chipid,linknumber;
END;

-- CREATE STORED PROCEDURE TO AVERAGE D LINKS
CREATE PROCEDURE SP_GETDAVERAGE(IN InSupernode integer, IN InChipID integer, IN InLinkNumber integer)
BEGIN
        INSERT INTO isnm_perf_dlink_sum(period,supernode,chipid,linknumber,cyclesblockedavg,flitssentavg,flitsdroppedavg,linklevelretriesavg)
        SELECT period,supernode,chipid,linknumber,AVG(cyclesblocked),AVG(flitssent),AVG(flitsdropped),AVG(linklevelretries) FROM isnm_perf_dlink
        WHERE (supernode = InSupernode AND chipid = InChipID AND linknumber = InLinkNumber)
        GROUP BY period,supernode,chipid,linknumber;
END;

-- CREATE STORED PROCEDURE TO AVERAGE ISR-HFI RAMPS
CREATE PROCEDURE SP_GETISRAVERAGE(IN InSupernode integer, IN InChipID integer, IN InIsrNumber integer)
BEGIN
        INSERT INTO isnm_perf_isr_sum(period,supernode,chipid,hfi_id,flitssentavg,flitsdroppedavg)
        SELECT period,supernode,chipid,hfi_id,AVG(flitssent),AVG(flitsdropped) FROM isnm_perf_isr
        WHERE (supernode = InSupernode and chipid = InChipID and hfi_id = InIsrNumber)
        GROUP BY period,supernode,chipid,hfi_id;
END;

-- CREATE STORED PROCEDURE TO AVERAGE HFI AGGREGATE COUNTERS
CREATE PROCEDURE SP_GETHFIAVERAGE(IN InSupernode integer, IN InChipID integer, IN InHfiNumber integer)
BEGIN
        INSERT INTO isnm_perf_hfi_sum(period,supernode,chipid,hfinumber,packetssentavg,packetsdroppedsendavg,packetrecievedavg,packetsdroppedreceiveavg,immediateppacketsendavg,sendreceivepacketsentavg,fullrdmapacketsentavg,halfrdmapacketsentavg,smallrdmapacketsentavg,ippacketsentavg,caupacketsentavg,gupspacketsentavg)
        SELECT period,supernode,chipid,hfinumber,AVG(packetssent),AVG(packetsdroppedsend),AVG(packetrecieved),AVG(packetsdroppedreceive),AVG(immediateppacketsend),AVG(sendreceivepacketsent),AVG(fullrdmapacketsent),AVG(halfrdmapacketsent),AVG(smallrdmapacketsent),AVG(ippacketsent),AVG(caupacketsent),AVG(gupspacketsent) from isnm_perf_hfi
        WHERE (supernode = InSupernode and chipid = InChipID and hfinumber = InHfiNumber)
        GROUP BY period,supernode,chipid,hfinumber;
END;
//

delimiter ;

-- CREATE VIEWS ON TOP DEPENDENT XCAT TABLES
-- CREATE VIEW ON TOP SITE TABLE
CREATE VIEW VNM_xcat_site AS
            SELECT site.key AS nm_name , site.value AS nm_value from site;

-- CREATE VIEW ON TOP NODELIST TABLE
CREATE VIEW VNM_xcat_nodelist AS
            SELECT nodelist.node AS nm_node, nodelist.groups AS nm_groups FROM nodelist;

-- CREATE VIEW ON TOP PPC TABLE
CREATE VIEW VNM_xcat_ppc AS
            SELECT ppc.node AS nm_node, ppc.id AS nm_id, ppc.parent AS nm_parent, ppc.nodetype AS nm_nodetype, ppc.supernode AS nm_supernode FROM ppc;

-- add foreign keys to isnm_perf table
alter table isnm_perf_lllink add foreign key (perfid) REFERENCES isnm_perf  (perfid) ON DELETE CASCADE;
alter table isnm_perf_lrlink add foreign key (perfid) REFERENCES isnm_perf  (perfid) ON DELETE CASCADE;
alter table isnm_perf_dlink add foreign key (perfid) REFERENCES isnm_perf  (perfid) ON DELETE CASCADE;
alter table isnm_perf_isr add foreign key (perfid) REFERENCES isnm_perf  (perfid) ON DELETE CASCADE;
alter table isnm_perf_hfi add foreign key (perfid) REFERENCES isnm_perf  (perfid) ON DELETE CASCADE;

-- add foreign keys to isnm_perf_sum table
alter table isnm_perf_lllink_sum add foreign key (period) REFERENCES isnm_perf_sum  (period) ON DELETE CASCADE;
alter table isnm_perf_lrlink_sum add foreign key (period) REFERENCES isnm_perf_sum  (period) ON DELETE CASCADE;
alter table isnm_perf_dlink_sum add foreign key (period) REFERENCES isnm_perf_sum  (period) ON DELETE CASCADE;
alter table isnm_perf_hfi_sum add foreign key (period) REFERENCES isnm_perf_sum  (period) ON DELETE CASCADE;
alter table isnm_perf_isr_sum add foreign key (period) REFERENCES isnm_perf_sum  (period) ON DELETE CASCADE;
